@@ -210,17 +210,11 @@ impl AssetsDatabase {
     }
 
     pub fn fetch_engine(&self) -> Option<&dyn FetchEngine> {
-        match self.fetch_engines.last() {
-            Some(engine) => Some(engine.as_ref()),
-            _ => None,
-        }
+        self.fetch_engines.last().map(|engine| engine.as_ref())
     }
 
-    pub fn fetch_engine_mut(&mut self) -> Option<&mut dyn FetchEngine> {
-        match self.fetch_engines.last_mut() {
-            Some(engine) => Some(engine.as_mut()),
-            _ => None,
-        }
+    pub fn fetch_engine_mut(&mut self) -> Option<&mut (dyn FetchEngine + 'static)> {
+        self.fetch_engines.last_mut().map(|engine| engine.as_mut())
     }
 
     pub fn with_fetch_engine<F, R>(&mut self, mut action: F) -> Option<R>
@@ -443,11 +437,14 @@ impl AssetsDatabase {
 #[cfg(test)]
 mod tests {
     use super::*;
-    use crate::assets::protocols::prelude::*;
+    use crate::assets::protocols::{
+        set::{SetAsset, SetAssetProtocol},
+        text::{TextAsset, TextAssetProtocol},
+    };
     use crate::fetch::*;
 
     #[test]
-    fn test_general() {
+    fn test_database() {
         let mut fetch_engine = engines::map::MapFetchEngine::default();
         fetch_engine.map.insert(
             "assets.txt".to_owned(),
