@@ -5,13 +5,6 @@ pub mod protocol;
 pub mod protocols;
 pub mod system;
 
-pub mod prelude {
-    pub use super::{
-        asset::*, asset_pack_preloader::*, database::*, protocol::*, protocols::prelude::*,
-        protocols::*, system::*,
-    };
-}
-
 use crate::{
     app::AppBuilder,
     assets::{
@@ -21,17 +14,19 @@ use crate::{
             pack::PackAssetProtocol, prefab::PrefabAssetProtocol, set::SetAssetProtocol,
             text::TextAssetProtocol, yaml::YamlAssetProtocol,
         },
-        system::AssetsSystem,
+        system::{assets_system, AssetsSystemResources},
     },
+    ecs::pipeline::{PipelineBuilder, PipelineBuilderError},
     fetch::FetchEngine,
-    localization::LocalizationSystem,
 };
 
-pub fn bundle_installer<FE: 'static, ADS>(
-    builder: &mut AppBuilder,
+pub fn bundle_installer<PB, FE, ADS>(
+    builder: &mut AppBuilder<PB>,
     (fetch_engine, mut assets_database_setup): (FE, ADS),
-) where
-    FE: FetchEngine,
+) -> Result<(), PipelineBuilderError>
+where
+    PB: PipelineBuilder,
+    FE: FetchEngine + 'static,
     ADS: FnMut(&mut AssetsDatabase),
 {
     let mut database = AssetsDatabase::new(fetch_engine);
@@ -44,6 +39,6 @@ pub fn bundle_installer<FE: 'static, ADS>(
     database.register(LocalizationAssetProtocol);
     assets_database_setup(&mut database);
     builder.install_resource(database);
-    builder.install_thread_local_system(AssetsSystem);
-    builder.install_thread_local_system(LocalizationSystem::default());
+    builder.install_system::<AssetsSystemResources>("assets", assets_system, &[])?;
+    Ok(())
 }
